1;

# Ensure that disp(@char) is locally defined
clear -f
addpath (fileparts (mfilename ("fullpath")));

function which (x)
endfunction

function s = fprintf (varargin)
    if nargout == 1
        s = [];
    endif
endfunction

# Remove 'frames' from the list of tests to run
global LTFAT_TESTS_TODO
LTFAT_TESTS_TODO = {'dgt', 'dwilt', 'wmdct',...
                    'dgt_fb','multiwin','gabfirtight',...
                    'purefreq','zak',...
                    'gabmulappr',...
                    'dgt2','dwilt2','wmdct2',...
                    'firwin',...
                    'spread', 'dsft', 'thresh',...
                    'pconv','lconv','involute',...
                    'signals','realout','windrivers',...
                    'nsdgt','filterbank',...
                    'pgauss','pfilt',...
                    'rangecompress',...
                    'gabmuleigs','phaselock',...
                    'fwt','blockfwt','ufwt','wfbt','uwfbt','wpfbt','uwpfbt','fwt2','undeceq',...
                    'wfbt2filterbank','freqorder','gga','chirpzt',...
                    'frametf', 'frft', 'nonu2ufilterbank', 'dtwfb', 'dtwfb2filterbank',...
                    'ambiguityfunction','wignervilledist','constructphase','multidgtrealmp'};

disp ("[running test_all_ltfat (without frames)]");
test_all_ltfat ('double');
