### Print only the banners of the unit tests
function disp (s)
    if ! isempty (regexp (s, "^( ?[=-]+ *TEST.*|.* TESTS (PASSED|FAILED).*|.*failed tests.*|   )"))
        printf (s);
        printf ("\n");
    endif
endfunction
